@@ -5,11 +5,13 @@
 */
 #pragma once
 
-#include <Akonadi/Calendar/ETMCalendar>
-#include <Collection>
+#include <Akonadi/Collection>
+#include <Akonadi/ETMCalendar>
 
 #include <QObject>
 
+#include <memory>
+
 namespace Akonadi
 {
 class Item;
@@ -68,7 +70,7 @@ Q_SIGNALS:
     void actionFinished(const Akonadi::Item &item);
 
 private:
-    CalendarUtilsPrivate *const d_ptr;
+    std::unique_ptr<CalendarUtilsPrivate> const d_ptr;
     Q_DECLARE_PRIVATE(CalendarUtils)
 
     Q_PRIVATE_SLOT(
